<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Use simplified menu structure without submenus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Use flat menus (no submenus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Boot to</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Menu timeout</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Kernel parameters</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>seconds</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Enable saving last boot choice</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Manage UEFI Boot Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Background</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Enable theme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Preview</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Very detailed</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detailed (default setting)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limited</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Display log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Display help </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>About this application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>About...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Quit application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Apply</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Still running</source>
        <translation>Still running</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>Process still running. Are you sure you want to quit?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Set timeout</source>
        <translation>Set timeout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Timeout in seconds:</source>
        <translation>Timeout in seconds:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="1034"/>
        <source>Timeout: %1 seconds</source>
        <translation>Timeout: %1 seconds</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="424"/>
        <location filename="../mainwindow.cpp" line="1033"/>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Boot Next: %1</source>
        <translation>Boot Next: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Removal confirmation</source>
        <translation>Removal confirmation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Are you sure you want to delete this boot entry?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Select EFI file</source>
        <translation>Select EFI file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI files (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="507"/>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Could not find the source mountpoint for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Set name</source>
        <translation>Set name</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Enter the name for the UEFI menu item:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Something went wrong, could not add entry.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installing bootsplash, please wait</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>Updating sources</source>
        <translation>Updating sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Installing</source>
        <translation>Installing</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not install the bootsplash.</source>
        <translation>Could not install the bootsplash.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Boot Current: %1</source>
        <translation>Boot Current: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Cannot continue</source>
        <translation>Cannot continue</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Nothing was selected, cannot change boot options. Exiting...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Could not create a temporary folder</source>
        <translation>Could not create a temporary folder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="514"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Cannot create chroot environment, cannot change boot options. Exiting...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Something went wrong, could not save boot order.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="772"/>
        <location filename="../mainwindow.cpp" line="1140"/>
        <source>Updating configuration, please wait</source>
        <translation>Updating configuration, please wait</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="821"/>
        <source>Updating initramfs...</source>
        <translation>Updating initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <location filename="../mainwindow.cpp" line="1152"/>
        <source>Updating grub...</source>
        <translation>Updating grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Done</source>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Changes have been successfully applied.</source>
        <translation>Changes have been successfully applied.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">About</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program for selecting common start-up choices</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">License</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancel</translation>
    </message>
    <message>
        <source>MX Boot Options</source>
        <translation type="vanished">MX Boot Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Running in a Virtual Machine</source>
        <translation>Running in a Virtual Machine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth packages not installed</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth packages are not currently installed.
OK to go ahead and install them?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Images (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>Press any key to close</source>
        <translation>Press any key to close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1010"/>
        <source>Log not found</source>
        <translation>Log not found</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1010"/>
        <source>Could not find log at </source>
        <translation>Could not find log at </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1016"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Edit UEFI Boot Entries</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1019"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1022"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Set ac&amp;tive</source>
        <translation>Set ac&amp;tive</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Add entry</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>Boot &amp;next</source>
        <translation>Boot &amp;next</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1025"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1026"/>
        <source>Move &amp;down</source>
        <translation>Move &amp;down</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1027"/>
        <source>&amp;Remove entry</source>
        <translation>&amp;Remove entry</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1028"/>
        <source>Re&amp;set next</source>
        <translation>Re&amp;set next</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1029"/>
        <source>Change &amp;timeout</source>
        <translation>Change &amp;timeout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1030"/>
        <source>Move &amp;up</source>
        <translation>Move &amp;up</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>not set, will boot using list order</source>
        <translation>not set, will boot using list order</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>Set &amp;inactive</source>
        <translation>Set &amp;inactive</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1118"/>
        <source>Needs reboot</source>
        <translation>Needs reboot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1118"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth was just installed, you might need to reboot before being able to display previews</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1173"/>
        <source>Click to select theme</source>
        <translation>Click to select theme</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program for selecting common start-up choices</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>You seem to be logged in as root, please log out and log in as normal user to use this program.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>Select image to display in bootloader</source>
        <translation>Select image to display in bootloader</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1183"/>
        <source>Select GRUB theme</source>
        <translation>Select GRUB theme</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation type="unfinished">License</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
</context>
</TS>
